==> 0.0.2.tar.gz: lib/components/senior_checkbox.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

abstract class SeniorCheckboxTheme {
  static Color getCheckboxColor({
    required Brightness theme,
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.primaryColor;
    }
    return SeniorColors.secondaryColor300;
  }

  static Color getCheckboxTitleColor({
    required Brightness theme,
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorCheckbox extends StatelessWidget {
  final String title;
  final bool value;
  final bool disabled;
  final Function(bool? value)? onChanged;

  SeniorCheckbox({
    required Key key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
  }) : super(key: key);  

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.fromLTRB(0, 0, 8.0, 0),
          child: SizedBox(
            width: Checkbox.width,
            height: Checkbox.width,
            child: Container(
              decoration: new BoxDecoration(
                border: Border.all(
                  color: SeniorCheckboxTheme.getCheckboxColor(theme: theme, isDisabled: this.disabled),
                  width: 1,
                ),
                borderRadius: new BorderRadius.circular(3),
              ),
              child: Theme(
                data: ThemeData(
                  unselectedWidgetColor: Colors.transparent,
                  disabledColor: Colors.transparent,
                ),
                child: Checkbox(
                  value: this.value,
                  onChanged: !this.disabled ? this.onChanged : null,
                  activeColor: Colors.transparent,
                  checkColor: SeniorCheckboxTheme.getCheckboxColor(theme: theme, isDisabled: this.disabled),
                  materialTapTargetSize: MaterialTapTargetSize.padded,
                ),
              ),
            ),
          ),
        ),
        Flexible(
          child: Text(
            this.title,
            style: SeniorTypography.getTextStyle(
              token: SeniorTypographyTokens.text,
              color: SeniorCheckboxTheme.getCheckboxTitleColor(theme: theme, isDisabled: this.disabled),
            ),
          ),
        ),
      ],
    );
  }
}

==> 0.2.0.tar.gz: lib/components/senior_checkbox.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorCheckboxTheme {
  SeniorCheckboxTheme._();

  static Color getCheckboxColor({
    required Brightness theme,
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.primaryColor;
    }
    return SeniorColors.secondaryColor300;
  }

  static Color getCheckboxTitleColor({
    required Brightness theme,
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorCheckbox extends StatelessWidget {
  final String title;
  final bool value;
  final bool disabled;
  final Function(bool?)? onChanged;

  const SeniorCheckbox({
    Key? key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
  }) : super(key: key);  

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.fromLTRB(0, 0, 8.0, 0),
          child: SizedBox(
            width: Checkbox.width,
            height: Checkbox.width,
            child: Container(
              decoration: new BoxDecoration(
                border: Border.all(
                  color: SeniorCheckboxTheme.getCheckboxColor(theme: theme, isDisabled: this.disabled),
                  width: 1,
                ),
                borderRadius: new BorderRadius.circular(3),
              ),
              child: Theme(
                data: ThemeData(
                  unselectedWidgetColor: Colors.transparent,
                  disabledColor: Colors.transparent,
                ),
                child: Checkbox(
                  value: this.value,
                  onChanged: !this.disabled ? this.onChanged : null,
                  activeColor: Colors.transparent,
                  checkColor: SeniorCheckboxTheme.getCheckboxColor(theme: theme, isDisabled: this.disabled),
                  materialTapTargetSize: MaterialTapTargetSize.padded,
                ),
              ),
            ),
          ),
        ),
        Flexible(
          child: Text(
            this.title,
            style: SeniorTypography.getTextStyle(
              token: SeniorTypographyTokens.text,
              color: SeniorCheckboxTheme.getCheckboxTitleColor(theme: theme, isDisabled: this.disabled),
            ),
          ),
        ),
      ],
    );
  }
}
